from . import uml

if __name__ == "__main__":
    uml.classdiagram()
